# FRED

https://loosolab.pages.gwdg.de/software/metadata-organizer/


# How to install

1. Clone the repository 
```
git clone git@gitlab.gwdg.de:loosolab/software/metadata-organizer.git
```
2. Move to the new repository directory
```
cd metadata-organizer
```
3. Create a pip environment
```
python3 -m venv .venv
```
4. Activate the environment
```
source .venv/bin/activate
```
5. Install the package
```
pip install .
```
